/*
 * Copyright (C) 2011 4th Line GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.fourthline.sash;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.view.Menu;
import android.view.MenuItem;
import org.fourthline.android.util.Util;
import org.fourthline.sash.mediaserver.MediaServerServiceImpl;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * @author Christian Bauer
 */
public class MainActivity extends Activity {

    private static final Logger log = Logger.getLogger(MainActivity.class.getName());

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        initLogging();

        startService(new Intent(this, MediaServerServiceImpl.class));
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();

        stopService(new Intent(this, MediaServerServiceImpl.class));
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        menu.add(0, 0, 0, R.string.rescan_media).setIcon(android.R.drawable.ic_menu_search);
        menu.add(0, 1, 0, R.string.exit).setIcon(android.R.drawable.ic_menu_close_clear_cancel);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case 0:
                // TODO: How to rescan internal memory?
                sendBroadcast(new Intent(
                        Intent.ACTION_MEDIA_MOUNTED,
                        Uri.parse("file://" + Environment.getExternalStorageDirectory())
                ));
                break;
            case 1:
                finish();
        }
        return false;
    }

    protected void initLogging() {
        Util.initLogging();
        Logger.getLogger("org.fourthline.cling").setLevel(Level.INFO);
        Logger.getLogger("org.fourthline.android").setLevel(Level.FINEST);
        Logger.getLogger("org.fourthline.sash").setLevel(Level.FINEST);

        /*
        // Network config
        Logger.getLogger("org.fourthline.cling.transport.spi.NetworkAddressFactory").setLevel(Level.FINEST);

        // UDP communication
        Logger.getLogger("org.fourthline.cling.transport.spi.DatagramIO").setLevel(Level.FINE);
        Logger.getLogger("org.fourthline.cling.transport.spi.MulticastReceiver").setLevel(Level.FINE);

        // Discovery
        Logger.getLogger("org.fourthline.cling.protocol.ProtocolFactory").setLevel(Level.FINER);
        Logger.getLogger("org.fourthline.cling.protocol.async").setLevel(Level.FINER);

        // Description
        Logger.getLogger("org.fourthline.cling.protocol.ProtocolFactory").setLevel(Level.FINER);
        Logger.getLogger("org.fourthline.cling.protocol.RetrieveRemoteDescriptors").setLevel(Level.FINE);
        Logger.getLogger("org.fourthline.cling.transport.spi.StreamClient").setLevel(Level.FINEST);

        Logger.getLogger("org.fourthline.cling.protocol.sync.ReceivingRetrieval").setLevel(Level.FINE);
        Logger.getLogger("org.fourthline.cling.binding.xml.DeviceDescriptorBinder").setLevel(Level.FINE);
        Logger.getLogger("org.fourthline.cling.binding.xml.ServiceDescriptorBinder").setLevel(Level.FINE);
        Logger.getLogger("org.fourthline.cling.transport.spi.SOAPActionProcessor").setLevel(Level.FINEST);

        // Registry
        Logger.getLogger("org.fourthline.cling.registry.Registry").setLevel(Level.FINER);
        Logger.getLogger("org.fourthline.cling.registry.LocalItems").setLevel(Level.FINER);
        Logger.getLogger("org.fourthline.cling.registry.RemoteItems").setLevel(Level.FINER);
        */
    }
}
